====================
atsphinx-highlightjs
====================

Override code-block output for highlight.js

Getting started
===============

.. code:: console

   pip install atsphinx-highlightjs

Usage
=====

Set extension into your ``conf.py`` of Sphinx documentation.

.. code:: python

   extensions = [
       # Add extension with others.
       "atsphinx.highlightjs",
   ]

License
=======

Apache-2.0 license. Please see `LICENSE <./LICENSE>`_.
